declare class VueEar {
    name: string;
    private bus;
    /**
     * VueEar Constructor
     * @constructor
     * @return {null|VueEar}
     * @param name
     */
    constructor(name?: string);
    /**
     * Get full name of event including name.
     * @param {string} event
     */
    id(event: string): string;
    /**
     * Listen to events.
     * @param {string} event - Name of event to listen to.
     * @param {function} run - Function to run when event talks.
     * @return {VueEar}
     */
    on(event: string, run: (...args: any[]) => any | void): this;
    /**
     * Talk to events
     * @param {string} event - Name of event to talk to.
     * @param {object} data - Data to send along with your speech
     * @param {boolean} [$addName]
     * @return {VueEar}
     */
    emit(event: string, data?: Record<string, any>): this;
    /**
     * Talk to global events
     * @param  {string} ear
     * @param {string} event - Name of event to talk to.
     * @param {object} data - Data to send along with your speech
     * @return {VueEar}
     */
    talkTo(ear: string, event: string, data?: {}): this | undefined;
    /**
     * Stop Listening to events
     * @param {string} event - Name of event to stop listening to
     * @param run
     * @return {VueEar}
     */
    off(event: string, run?: (...args: any[]) => any | void): this;
    destroy(): null;
}
/**
 * Use existing ear or create new
 * @param ear
 * @param $class
 */
export declare function useEar<T extends typeof VueEar>(ear: string, $class: T): InstanceType<T>;
/**
 * Use existing ear or create new
 * @param ear
 */
export declare function useVueEar(ear: string): VueEar;
export default VueEar;
